﻿using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using System.Web.Mvc;
using Syncfusion.OfficeChart;
using System.Collections.Generic;
using System.Drawing;
using System;
using System.Data;
using System.Collections;
using System.IO;

namespace CreateWordSample.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
           
            return View();
        }
        public ActionResult CreateDocument()
        {
            string input = Server.MapPath(@"..//Data//Template.docx").ToString();
			//Opens Word document
            WordDocument document = new WordDocument(input);
            //Iterates into section
            foreach(WSection section in document.Sections)
            {
                //Interates into textbody
                IterateTextBody(section.Body);
            }
            //Saves and closes the document instance
            document.Save("Result.docx", FormatType.Docx, HttpContext.ApplicationInstance.Response, HttpContentDisposition.Attachment);
            document.Close();

            return View();
        }
        /// <summary>
        /// Iterates into text body
        /// </summary>
        /// <param name="textBody"></param>
        private void IterateTextBody(WTextBody textBody)
        {
            //Iterates through each of the child items of WTextBody
            for (int i = 0; i < textBody.ChildEntities.Count; i++)
            {
                //IEntity is the basic unit in DocIO DOM. 
                //Accesses the body items (should be either paragraph or table) as IEntity
                IEntity bodyItemEntity = textBody.ChildEntities[i];
                //A Text body has 2 types of elements - Paragraph and Table
                //Decides the element type by using EntityType
                switch (bodyItemEntity.EntityType)
                {
                    case EntityType.Paragraph:
                        //Gets paragraph from the section
                        WParagraph paragraph = bodyItemEntity as WParagraph;
                        //Iterates into paragraph
                        for (int j = 0; j < paragraph.ChildEntities.Count; j++)
                        {
                            //Checks the entity is Picture
                            if (paragraph.ChildEntities[j] is WPicture)
                            {
                                //Gets picture of the paragraph
                                WPicture pic = (WPicture)paragraph.ChildEntities[j];
                                //Gets width and height of the picture
                                float initialHeight = pic.Height;
                                float initialWidth = pic.Width;
                                //Finds and replace the picture with new picture
                                ReplaceImage("Red BiCycle", pic, paragraph, j);
                                //Sets original size for the new picture
                                pic.Height = initialHeight;
                                pic.Width = initialWidth;
                            }
                        }
                        break;
                    case EntityType.Table:
                        //Table is a collection of rows and cells
                        //Iterates through table's DOM
                        IterateTable(bodyItemEntity as WTable);
                        break;
                }
            }
        }
        /// <summary>
        /// Iterates into table
        /// </summary>
        /// <param name="table"></param>
        private void IterateTable(WTable table)
        {
            //Iterates the row collection in a table
            foreach (WTableRow row in table.Rows)
            {
                //Iterates the cell collection in a table row
                foreach (WTableCell cell in row.Cells)
                {
                    //Table cell is derived from (also a) TextBody
                    //Reusing the code meant for iterating TextBody
                    IterateTextBody(cell);
                }
            }
        }
        /// <summary>
        /// Finds and replace the picture with new picture
        /// </summary>
        /// <param name="alternateText"></param>
        /// <param name="picture"></param>
        /// <param name="paragraph"></param>
        /// <param name="index"></param>
        private void ReplaceImage(string alternateText, WPicture picture, WParagraph paragraph, int index)
        {
            //Finds particular picture by its alternative text.
            if (picture.AlternativeText == alternateText)
            {
                //Open the image in filestream
                FileStream fs = new FileStream(Server.MapPath(@"..//Data//Image3.png").ToString(), FileMode.Open, FileAccess.Read);
                //Create image from the file stream
                System.Drawing.Image newImage = System.Drawing.Image.FromStream(fs);
                //Removes the picture from the index
                paragraph.ChildEntities.RemoveAt(index);
                //Inserts new picture at the same index of the paragraph
                paragraph.ChildEntities.Insert(index, paragraph.AppendPicture(newImage));
            }
        }
        public ActionResult About()
        {
            ViewBag.Message = "Your application description page.";

            return View();
        }

        public ActionResult Contact()
        {
            ViewBag.Message = "Your contact page.";

            return View();
        }
    }
}